==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/merchant/MerchantBindingUserAndHelperReqBean.java <==
package global.hh.openapi.sdk.api.bean.merchant;


/**
 * @description: 提供给小U,当用户绑定加小助手为好友时触发
 * @author: 777771
 * @date: 2020-32-13 16:32:44
 */
public class MerchantBindingUserAndHelperReqBean {
    /**
     * 用户微信id
     */
    private String wxId;

    /**
     * 用户微信昵称
     */
    private String wxName;

    /**
     * 小助手编号
     */
    private String helperWxId;

    /**
     * 小助手昵称
     */
    private String helperWxName;

    /**
     * 小助手状态(10 正常 14异常 20封号)
     */
    private String helperStatus;

    /**
     * 小助手二维码
     */
    private String helperQRCode;

    /**
     * 用户绑定状态 1-已绑定 0-未绑定 2-解除绑定 3-冻结
     */
    private String status;

    /**
     * 用户绑定时间
     */
    private String bindingTime;

    public MerchantBindingUserAndHelperReqBean(){
    }

    public MerchantBindingUserAndHelperReqBean(String wxId,String wxName,String helperWxId,String helperWxName,String helperStatus,String helperQRCode,String status,String bindingTime){
        this.wxId=wxId;
        this.wxName=wxName;
        this.helperWxId=helperWxId;
        this.helperWxName=helperWxName;
        this.helperStatus=helperStatus;
        this.helperQRCode=helperQRCode;
        this.status=status;
        this.bindingTime=bindingTime;
    }

    private String getWxId() {
        return wxId;
    }

    private void setWxId(String wxId) {
        this.wxId = wxId;
    }
    private String getWxName() {
        return wxName;
    }

    private void setWxName(String wxName) {
        this.wxName = wxName;
    }
    private String getHelperWxId() {
        return helperWxId;
    }

    private void setHelperWxId(String helperWxId) {
        this.helperWxId = helperWxId;
    }
    private String getHelperWxName() {
        return helperWxName;
    }

    private void setHelperWxName(String helperWxName) {
        this.helperWxName = helperWxName;
    }
    private String getHelperStatus() {
        return helperStatus;
    }

    private void setHelperStatus(String helperStatus) {
        this.helperStatus = helperStatus;
    }
    private String getHelperQRCode() {
        return helperQRCode;
    }

    private void setHelperQRCode(String helperQRCode) {
        this.helperQRCode = helperQRCode;
    }
    private String getStatus() {
        return status;
    }

    private void setStatus(String status) {
        this.status = status;
    }
    private String getBindingTime() {
        return bindingTime;
    }

    private void setBindingTime(String bindingTime) {
        this.bindingTime = bindingTime;
    }
}

==> biostime-openapi-sdk-1.5.8.8-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/merchant/MerchantBindingUserAndHelperReqBean.java <==
package global.hh.openapi.sdk.api.bean.merchant;


/**
 * @description: 提供给小U,当用户绑定加小助手为好友时触发
 * @author: 3742
 * @date: 2020-42-13 16:42:38
 */
public class MerchantBindingUserAndHelperReqBean {
    /**
     * 用户微信id
     */
    private String wxId;

    /**
     * 用户微信昵称
     */
    private String wxName;

    /**
     * 小助手编号
     */
    private String helperWxId;

    /**
     * 小助手昵称
     */
    private String helperWxName;

    /**
     * 小助手状态(10 正常 14异常 20封号)
     */
    private String helperStatus;

    /**
     * 小助手二维码
     */
    private String helperQRCode;

    /**
     * 用户绑定状态 1-已绑定 0-未绑定 2-解除绑定 3-冻结
     */
    private String status;

    /**
     * 用户绑定时间
     */
    private String bindingTime;

    public MerchantBindingUserAndHelperReqBean(){
    }

    public MerchantBindingUserAndHelperReqBean(String wxId,String wxName,String helperWxId,String helperWxName,String helperStatus,String helperQRCode,String status,String bindingTime){
        this.wxId=wxId;
        this.wxName=wxName;
        this.helperWxId=helperWxId;
        this.helperWxName=helperWxName;
        this.helperStatus=helperStatus;
        this.helperQRCode=helperQRCode;
        this.status=status;
        this.bindingTime=bindingTime;
    }

    public String getWxId() {
        return wxId;
    }

    public void setWxId(String wxId) {
        this.wxId = wxId;
    }
    public String getWxName() {
        return wxName;
    }

    public void setWxName(String wxName) {
        this.wxName = wxName;
    }
    public String getHelperWxId() {
        return helperWxId;
    }

    public void setHelperWxId(String helperWxId) {
        this.helperWxId = helperWxId;
    }
    public String getHelperWxName() {
        return helperWxName;
    }

    public void setHelperWxName(String helperWxName) {
        this.helperWxName = helperWxName;
    }
    public String getHelperStatus() {
        return helperStatus;
    }

    public void setHelperStatus(String helperStatus) {
        this.helperStatus = helperStatus;
    }
    public String getHelperQRCode() {
        return helperQRCode;
    }

    public void setHelperQRCode(String helperQRCode) {
        this.helperQRCode = helperQRCode;
    }
    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }
    public String getBindingTime() {
        return bindingTime;
    }

    public void setBindingTime(String bindingTime) {
        this.bindingTime = bindingTime;
    }
}
